
# Slot: version


particular version of schema

URI: [linkml:version](https://w3id.org/linkml/version)


## Domain and Range

schema_definition &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * schema_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | pav:version |
|  | | schema:schemaVersion |
| **In Subsets:** | | owl |

